@@ -1,4 +1,4 @@
-/* $Id: cterm.c,v 1.125 2009/02/19 02:39:00 deuce Exp $ */
+/* $Id: cterm.c,v 1.126 2011/04/21 20:34:20 deuce Exp $ */
 
 /****************************************************************************
  * @format.tab-size 4		(Plain Text/Source Code File Header)			*
@@ -1181,7 +1181,7 @@ void do_ansi(char *retbuf, size_t retsize, int *speed)
 
 void cterm_init(int height, int width, int xpos, int ypos, int backlines, unsigned char *scrollback, int emulation)
 {
-	char	*revision="$Revision: 1.125 $";
+	char	*revision="$Revision: 1.126 $";
 	char *in;
 	char	*out;
 	int		i;
@@ -1346,7 +1346,7 @@ void ctputs(char *buf)
 	_wscroll=oldscroll;
 }
 
-char *cterm_write(unsigned char *buf, int buflen, char *retbuf, size_t retsize, int *speed)
+char *cterm_write(const unsigned char *buf, int buflen, char *retbuf, size_t retsize, int *speed)
 {
 	unsigned char ch[2];
 	unsigned char prn[BUFSIZE];
